@@ -41,6 +41,11 @@ mod views;
 use views::*;
 
 type AtomicClient = Arc<RwLock<TrashcanClient>>;
+const MESSAGES: [&'static str; 3] = [
+    "Network seems fine...",
+    "Your gateway needs rebooting!",
+    "Gateway is off or rebooting"
+];
 
 pub fn init() {
     println!("Collecting gateway statistics...");
@@ -242,11 +247,17 @@ pub fn init() {
                         let client: &AtomicClient = view.user_data().unwrap();
                         report_error!(status, client.write().unwrap().reboot_gateway(false));
                         view.quit();
+                        println!("Rebooting gateway...");
                     })
                 )
             })
         )
         .add_subtree("Diagnostics", menu::Tree::new()
+            .leaf("Check Network for Problems", |view| {
+                let mut status = view.find_name::<StatusView>("status").unwrap();
+                let message = MESSAGES[client::check_net_env(true)];
+                status.info(message);
+            })
             .leaf("Gateway Monitor Log", |view| {
                 let mut status = view.find_name::<StatusView>("status").unwrap();
                 let dates = client::get_log_dates();
@@ -394,7 +405,6 @@ pub fn init() {
         .add_leaf("Gateway Info", |view| {
             let mut status = view.find_name::<StatusView>("status").unwrap();
             let client: &AtomicClient = view.user_data().unwrap();
-            report_error!(status, client.write().unwrap().refresh_token());
             let info = report_error!(status, client.read().unwrap().get_info());
             view.add_layer(info_dialog("Gateway Info", info));
         })
